@@ -347,6 +347,9 @@
 #define __NR_copy_file_range	391
 #define __NR_preadv2	392
 #define __NR_pwritev2	393
+#define __NR_pkey_mprotect	394
+#define __NR_pkey_alloc	395
+#define __NR_pkey_free	396
 
 #define __ARM_NR_breakpoint	0x0f0001
 #define __ARM_NR_cacheflush	0x0f0002
@@ -703,3 +706,6 @@
 #define SYS_copy_file_range	391
 #define SYS_preadv2	392
 #define SYS_pwritev2	393
+#define SYS_pkey_mprotect	394
+#define SYS_pkey_alloc	395
+#define SYS_pkey_free	396
